@@ -51,6 +51,7 @@ from ..pure import remove_temp_file
 import shutil
 # --- 初始化环境 ---
 from .admin_env_init import CHANGE_LIST_HTML_PATH, TEMPDIR, BD_USE_GUARDIAN, CHANGE_FORM_TEMPLATE, BD_USE_SIMPLEUI
+from .admin_env_init import BD_USE_AJAX_ADMIN
 from tqdm import tqdm
 from pandas._libs.tslibs.timestamps import Timestamp
 from bddjango import get_base_model, get_model_max_id_in_db, old_get_model_max_id_in_db
@@ -66,16 +67,16 @@ import html
 
 IAdmin = admin.ModelAdmin
 
-if BD_USE_SIMPLEUI:
+if BD_USE_SIMPLEUI and BD_USE_AJAX_ADMIN:
     from simpleui.admin import AjaxAdmin
+
     IAdmin = AjaxAdmin
 
 if BD_USE_GUARDIAN:
     from guardian.admin import GuardedModelAdminMixin
 
-    class IAdmin(IAdmin, GuardedModelAdminMixin):
+    class IAdmin(GuardedModelAdminMixin, IAdmin):
         change_form_template = CHANGE_FORM_TEMPLATE
-    # IAdmin = _IAdmin
 
 
 class IDAdmin(IAdmin):
