@@ -72,11 +72,11 @@ if BD_USE_SIMPLEUI:
     IAdmin = AjaxAdmin
 
 
-if BD_USE_GUARDIAN:
-    from guardian.admin import GuardedModelAdmin
-
-    IAdmin = GuardedModelAdmin
-    IAdmin.change_form_template = CHANGE_FORM_TEMPLATE
+# if BD_USE_GUARDIAN:
+#     from guardian.admin import GuardedModelAdmin
+#
+#     IAdmin = GuardedModelAdmin
+#     IAdmin.change_form_template = CHANGE_FORM_TEMPLATE
 
 
 # region # --- 处理df中的特殊格式
@@ -336,6 +336,11 @@ class CsvImportForm(forms.Form):
 
 
 def _get_base_admin_dc_by_iadmin(iadmin):       # 类似装饰器模式, 通过IAdmin来获取装饰后的BaseAmin
+    if BD_USE_GUARDIAN:
+        from guardian.admin import GuardedModelAdminMixin
+
+        class iadmin(GuardedModelAdminMixin, iadmin):
+            change_form_template = CHANGE_FORM_TEMPLATE
 
     class IDAdmin(iadmin):
         """
@@ -746,6 +751,7 @@ def _get_base_admin_dc_by_iadmin(iadmin):       # 类似装饰器模式, 通过I
 from . import adminclass
 
 
+# decorator, 装饰器模式, 给admin_class附加额外的功能
 def get_base_admin_dc_by_iadmin(iadmin=IAdmin, key='BaseAdmin') -> adminclass.BaseAdmin:
     admin_dc = _get_base_admin_dc_by_iadmin(iadmin)
     admin_class = admin_dc.get(key)
@@ -753,16 +759,6 @@ def get_base_admin_dc_by_iadmin(iadmin=IAdmin, key='BaseAdmin') -> adminclass.Ba
 
 
 MyAjaxAdmin: adminclass.BaseAdmin = get_base_admin_dc_by_iadmin(AjaxAdmin)
-# ImportAdmin: adminclass.ImportAdmin = get_base_admin_dc_by_iadmin('ImportAdmin')
-# CsvImportExportAdmin: adminclass.CsvImportExportAdmin = get_base_admin_dc_by_iadmin('CsvImportExportAdmin')
-# ExcelImportExportAdmin: adminclass.ExcelImportExportAdmin = get_base_admin_dc_by_iadmin('ExcelImportExportAdmin')
-# ForceRunActionsAdmin: adminclass.ForceRunActionsAdmin = get_base_admin_dc_by_iadmin('ForceRunActionsAdmin')
-# ListDisplayAdmin: adminclass.ListDisplayAdmin = get_base_admin_dc_by_iadmin('ListDisplayAdmin')
-# BaseAdmin: adminclass.BaseAdmin = get_base_admin_dc_by_iadmin('BaseAdmin')
-
-# BaseAdmin
-# BaseAdmin.changelist_view()
-# print(1)
 
 
 class CustomIAdmin:
