@@ -378,8 +378,19 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
         query_dc = self.get_request_data()
         page_size = query_dc.get('page_size', self.pagination_class.page_size)
 
+        GET_ALL = -999      # 获取全部
         p = query_dc.get('p', 1)
-        my_api_assert_function(int(p) != 0, '页码p的值不能为0!')
+
+        try:
+            p = int(p)
+
+            if p == GET_ALL or int(page_size) == GET_ALL:
+                p = 1
+                page_size = 999999999
+
+            my_api_assert_function(p > 0, f'页码p[{p}]必须为[正整数]!')
+        except Exception as e:
+            my_api_assert_function(0, f'页码[p: {p}] 必须为[正整数]!')
 
         context = self.get_serializer_context()
 
